==> tutti-ui-swing-3.4-sources.jar: fr/ifremer/tutti/ui/swing/action/ImportSpeciesMultiPostAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportSpeciesMultiPostAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.4/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/ImportSpeciesMultiPostAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.data.CatchBatch;
import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.persistence.entities.data.SpeciesBatch;
import fr.ifremer.tutti.service.catches.multipost.MultiPostImportService;
import fr.ifremer.tutti.ui.swing.content.operation.catches.MultiPostImportLogDialog;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIHandler;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIModel;

import javax.swing.JTextArea;
import java.awt.Dialog;
import java.util.Collection;
import java.util.Map;

import static org.nuiton.i18n.I18n.t;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 2.2
 */
public class ImportSpeciesMultiPostAction extends AbstractImportMultiPostAction<SpeciesBatchUIModel, SpeciesBatchUI, SpeciesBatchUIHandler> {

    protected Map<String, Object> notImportedData;

    public ImportSpeciesMultiPostAction(SpeciesBatchUIHandler handler) {
        super(handler);
    }

    @Override
    protected String getFileExtension() {
        return "tuttiSpecies";
    }

    @Override
    protected String getFileExtensionDescription() {
        return t("tutti.common.file.tuttiSpecies");
    }

    @Override
    protected String getFileChooserTitle() {
        return t("tutti.editSpeciesBatch.action.importMultiPost.sourceFile.title");
    }

    @Override
    protected String getFileChooserButton() {
        return t("tutti.editSpeciesBatch.action.importMultiPost.sourceFile.button");
    }

    @Override
    public void releaseAction() {
        notImportedData = null;
        super.releaseAction();
    }

    @Override
    protected void importBatches(FishingOperation operation) {
        notImportedData = multiPostImportExportService.importSpecies(file, operation);
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();

        if (!notImportedData.isEmpty()) {
            MultiPostImportLogDialog dialog = new MultiPostImportLogDialog((Dialog) getContext().getActionUI());

            Collection<SpeciesBatch> notImportedSpeciesBatches =
                    (Collection<SpeciesBatch>) notImportedData.get(MultiPostImportService.BATCHES_KEY);

            StringBuffer stringBuffer = new StringBuffer();
            Float totalSortedWeight = (Float) notImportedData.get(CatchBatch.PROPERTY_SPECIES_TOTAL_SORTED_WEIGHT);
            if (totalSortedWeight != null) {
                stringBuffer.append("- " + t("tutti.multiPostImportLog.totalSortedWeight", totalSortedWeight) + "\n");
            }

            Float inertWeight = (Float) notImportedData.get(CatchBatch.PROPERTY_SPECIES_TOTAL_INERT_WEIGHT);
            if (inertWeight != null) {
                stringBuffer.append("- " + t("tutti.multiPostImportLog.inertWeight", inertWeight) + "\n");
            }

            Float livingNotItemizedWeight =
                    (Float) notImportedData.get(CatchBatch.PROPERTY_SPECIES_TOTAL_LIVING_NOT_ITEMIZED_WEIGHT);
            if (livingNotItemizedWeight != null) {
                stringBuffer.append("- " + t("tutti.multiPostImportLog.livingNotItemizedWeight", livingNotItemizedWeight) + "\n");
            }

            for (SpeciesBatch sb : notImportedSpeciesBatches) {
                stringBuffer.append("- " + decorate(sb.getSpecies()) + " / " + decorate(sb.getSampleCategoryValue()) + "\n");
            }

            if (stringBuffer.length() > 0) {
                JTextArea batchList = dialog.getBatchList();
                batchList.setText(stringBuffer.toString());
                dialog.setSize(400, 300);
                dialog.setLocationRelativeTo(getContext().getMainUI());
                dialog.setVisible(true);
            }
        }

        sendMessage(t("tutti.editSpeciesBatch.action.importMultiPost.success", file));
    }
}

==> tutti-ui-swing-3.4.1-sources.jar: fr/ifremer/tutti/ui/swing/action/ImportSpeciesMultiPostAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportSpeciesMultiPostAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.4.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/ImportSpeciesMultiPostAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.data.CatchBatch;
import fr.ifremer.tutti.persistence.entities.data.FishingOperation;
import fr.ifremer.tutti.persistence.entities.data.SpeciesBatch;
import fr.ifremer.tutti.service.catches.multipost.MultiPostImportService;
import fr.ifremer.tutti.ui.swing.content.operation.catches.MultiPostImportLogDialog;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUI;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIHandler;
import fr.ifremer.tutti.ui.swing.content.operation.catches.species.SpeciesBatchUIModel;

import javax.swing.JTextArea;
import java.awt.Dialog;
import java.util.Collection;
import java.util.Map;

import static org.nuiton.i18n.I18n.t;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 2.2
 */
public class ImportSpeciesMultiPostAction extends AbstractImportMultiPostAction<SpeciesBatchUIModel, SpeciesBatchUI, SpeciesBatchUIHandler> {

    protected Map<String, Object> notImportedData;

    public ImportSpeciesMultiPostAction(SpeciesBatchUIHandler handler) {
        super(handler);
    }

    @Override
    protected String getFileExtension() {
        return "tuttiSpecies";
    }

    @Override
    protected String getFileExtensionDescription() {
        return t("tutti.common.file.tuttiSpecies");
    }

    @Override
    protected String getFileChooserTitle() {
        return t("tutti.editSpeciesBatch.action.importMultiPost.sourceFile.title");
    }

    @Override
    protected String getFileChooserButton() {
        return t("tutti.editSpeciesBatch.action.importMultiPost.sourceFile.button");
    }

    @Override
    public void releaseAction() {
        notImportedData = null;
        super.releaseAction();
    }

    @Override
    protected void importBatches(FishingOperation operation) {
        notImportedData = multiPostImportExportService.importSpecies(file, operation);
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();

        if (!notImportedData.isEmpty()) {
            MultiPostImportLogDialog dialog = new MultiPostImportLogDialog((Dialog) getContext().getActionUI());

            Collection<SpeciesBatch> notImportedSpeciesBatches =
                    (Collection<SpeciesBatch>) notImportedData.get(MultiPostImportService.BATCHES_KEY);

            StringBuffer stringBuffer = new StringBuffer();
            Float totalSortedWeight = (Float) notImportedData.get(CatchBatch.PROPERTY_SPECIES_TOTAL_SORTED_WEIGHT);
            if (totalSortedWeight != null) {
                stringBuffer.append("- " + t("tutti.multiPostImportLog.totalSortedWeight", totalSortedWeight) + "\n");
            }

            Float inertWeight = (Float) notImportedData.get(CatchBatch.PROPERTY_SPECIES_TOTAL_INERT_WEIGHT);
            if (inertWeight != null) {
                stringBuffer.append("- " + t("tutti.multiPostImportLog.inertWeight", inertWeight) + "\n");
            }

            Float livingNotItemizedWeight =
                    (Float) notImportedData.get(CatchBatch.PROPERTY_SPECIES_TOTAL_LIVING_NOT_ITEMIZED_WEIGHT);
            if (livingNotItemizedWeight != null) {
                stringBuffer.append("- " + t("tutti.multiPostImportLog.livingNotItemizedWeight", livingNotItemizedWeight) + "\n");
            }

            for (SpeciesBatch sb : notImportedSpeciesBatches) {
                stringBuffer.append("- " + decorate(sb.getSpecies()) + " / " + decorate(sb.getSampleCategoryValue()) + "\n");
            }

            if (stringBuffer.length() > 0) {
                JTextArea batchList = dialog.getBatchList();
                batchList.setText(stringBuffer.toString());
                dialog.setSize(400, 300);
                dialog.setLocationRelativeTo(getContext().getMainUI());
                dialog.setVisible(true);
            }
        }

        sendMessage(t("tutti.editSpeciesBatch.action.importMultiPost.success", file));
    }
}
